#modelos multiplos

##########
#7b - uma estimativa da incerteza na previsao do modelo

##lendo os dados
babies <- read.table("babies.csv", header=T, sep="")

#peso do bebe de ona para Kg
# 1 ona = 0,0283495
babies$bwt <- (babies$bwt)*0.0283495
#plotando o grfico para ver a relao entre as duas variveis
plot(bwt~gestation, data=babies)

#corrigindo problemas nos dados da tabela
#colocar NA nos dados indicados
#bwt
babies$bwt[babies$bwt==999] <- NA
#gestao
babies$gestation[babies$gestation==999] <- NA
#parity
babies$parity[babies$parity==9] <- NA
#age
babies$age[babies$age==99] <- NA
#height
babies$height[babies$height==99] <- NA
#weight
babies$weight[babies$weight==999] <- NA
#smoke
babies$smoke[babies$smoke==9] <- NA
#excluir NAs
babies<-na.exclude(babies)

#grfico com o intervalo de confiana de 95% da previso do modelo
#para isso:
#1. estimar o intervalo de confia para diversos valores da varivel preditora
gesta.s <-(seq(min(babies$gestation), max(babies$gestation), length=100))
#2. criar o modelo
modgesta <- lm(bwt~gestation, babies)
#3. extrair os coeficientes do modelo criado
coef.modgesta <- coef(modgesta)
#4. calcular a mdia dos valores simulados
media <- mean(gesta.s)
#variancia dos valores de y observados
var <- var(babies$bwt)
#calculo do n
n.bwt <- length(babies$bwt)
#erros quadraticos
eq <- ((gesta.s - media)^2) 
#soma dos erros quadraticos
s.eq <- sum(eq)
#calculo do valor de t
babies.t <- qt(.975, (n.bwt-2))
#calculo do erro padrao
erro.pd <- sqrt (var*((1/n.bwt)+((eq)/s.eq)))
#calculo do y predito
y.pred <- coef.modgesta[1]+(coef.modgesta[2]*gesta.s)
#calculo do intervalo de confiana
inter.inf <- y.pred-(babies.t*erro.pd)
inter.sup <- y.pred+(babies.t*erro.pd)
#criando os graficos
plot(bwt~gestation, data=babies)
abline(modgesta, col="red")

##########
#7.b - Galileu estava certo?
init.h = c(600, 700, 800, 950, 1100, 1300, 1500)
h.d = c(253, 337, 395, 451, 495, 534, 573)
plot(h.d~init.h)
mod1 <- lm(h.d~init.h)
anova(mod1)
summary(mod1)
#R2 - mode1 =  0.9264
mod2 <- update(mod1,.~. +I(init.h^2))
anova(mod2)
summary(mod2)
#R2 - mode2 = 0.9903
mod3 <- update(mod1,.~. +I(init.h^2)+I(init.h^3))
anova(mod3)
summary(mod3)
#R2 - mode3 = 0.9994
#o mod3  um modelo melhor para descrever?
anova(mod1, mod2) #incluir o polinomio de segundo grau  significativo, manter mod2
anova(mod2, mod3) #incluir o polinomio de terceiro grau  significativo, manter mod3
#sim, o modelo com polinmio  o melhor modelo.
##########

##########
#7.c massa de recm-nascidos
#experimentar todas as variaveis para chegar ao melhor modelo de previsao:
#bwt = massa ao nascer
#gestation = duraao da gestaao em dias
#parity = 0 - primeira gestaao
#age = idade da mae em anos
#height = altura da mae em polegadas
#weight = massa da mae antes da gestaao
#smoke = a mae  fumante

#modelo
#modelo cheio - todas as variveis + uma interao que considero fazer sentido ao modelo:
mod.full <- lm(bwt~gestation+parity+age+height+weight+smoke+weight:smoke, data=babies)
summary(mod.cheio) - mod.full: 0.258

#mod.1 - tirar a interao
mod.1 <- lm(bwt~gestation+parity+age+height+weight+smoke, data=babies)
anova(mod.full, mod.1) #p=0.8641 - retenho modelo mais simples - mod.1
summary(mod.1)

#mod.2 - tirar age
mod.2 <- lm(bwt~gestation+parity+height+weight+smoke, data=babies)
anova(mod.1, mod.2) #p=0.917 - retenho modelo mais simples - mod.2
summary(mod.2)

#mod.3 - tirar weight
mod.3 <- lm(bwt~gestation+parity+height+smoke, data=babies)
anova(mod.2, mod.3) #p=0.04672 - retenho o modelo mais complexo - mod.2

#mod.4 - tirar parity
mod.4 <- lm(bwt~gestation+height+weight+smoke, data=babies)
anova(mod.2, mod.4) #p=0.002026 - retenho o modelo mais complexo - mod.2

#mod.5 - tirar height
mod.5 <- lm(bwt~gestation+parity+weight+smoke, data=babies)
anova(mod.2, mod.5) p=2.114e-08 - retenho o modelo mais complexo - mod.2

#mod.6 - tirar smoke
mod.6 <- lm(bwt~gestation+parity+height+weight, data=babies)
anova(mod.2, mod.6) p=2.2e-16 - retenho o modelo mais complexo - mod.2

#mod.7 - tirar gestation
mod.7 <- lm(bwt~parity+height+weight+smoke, data=babies)
anova(mod.2, mod.7) p=2.2e-16 - retenho o modelo mais complexo - mod.2

#modelo final selecionado foi o mod.2
#mod.2 <- lm(bwt~gestation+parity+height+weight+smoke)
















